data.createExperiments <- function(n,nexp,sanity_check) {

  #Creates random experimental setting.
  # n  - number of variables
  # nexp - number of experiments
  # sanity_check - if the sanity check experiments should be created
  #		   for paper results should be FALSE
  #Returning a nexp x n matrix where
  # each row is one experiment, each column is a variable,
  # where 1=intervened, 0=observed, -1=latent


  # Initialize the design matrix  

  E <- matrix(0,nexp,n)

  if ( !sanity_check ) {
    # Do each experiment separately, ensure that there is always
    # at least one intervention and at least one passively observed
    # variable!
    i <- 1
    while (i <= nexp)
    {
            ei <- sample(0:2, n, replace=TRUE)-1
            if (sum(ei==1)>0) #make sure one variable is intervened 
            {
                    if (sum(ei==0)>0) #and one variable is observed
                    {
                            E[i,] <- ei
                            i <- i+1
                    }
            }
    }
  } else {
  # this was used for sanity check
  # At least one latent per experiment
  # At least one variable that has never been intervened
    ok <- FALSE
    while( !ok ) {

      #Here calling the above code until a set of experiments with the characteristics
      #above are fulfilled.
      E<-data.createExperiments(n,nexp,FALSE)

      #sample experiments until the following characteristics are fulfilled

      # At least one variable that has never been intervened
      ok <- any(!apply(E==1,2,any))

      # At least one latent per experiment
      ok <- ok & all(apply(E==(-1),1,any))


    }

  }
 
  # Return the experiments matrix
  E
}