data.createModel <- function(n) {
  #Creating a random model.
  # n - number of variables.
  #Edge probability is 0.2 and probability of any confounder being present is 0.15.

  # Random structure (density 0 < p < 1)
  p <- 0.2
  B <- 1*(matrix(runif(n*n),n,n) < p)

  # Make sure diagonal is zero (we specify all models in this way
  # to take out unnecessary degrees of underdetermination)
  diag(B) <- 0

  # Random coefficients (with a lower bound)
  B <- B*matrix(runif(n*n,0.1,0.8),n,n)*matrix(sample(c(-1,1),n*n,replace=TRUE),n,n)
  
  # Create a sparse random covariance matrix for the disturbances
  p <- 0.15 / 2  #dividing by two since the matrix is symmetric
		 # to get the probability to be 15%
  Adist <- 1*(matrix(runif(n*n),n,n) < p)
  diag(Adist) <- 1
  Adist <- Adist*matrix(rnorm(n*n),n,n)
  Ce <- Adist %*% t(Adist)        

  # Return both
  res <- list()
  res$B <- B
  res$Ce <- Ce
  res
}