data.stats<-function(B,k=1:100) {

  #Prints the statistics for a list of matrices B and indexes k of the true models.
  # (So, only direct effects considered.)
  # where B[[k]][i,j] = -1 if B[i,j] was not known to be zero or nonzero
  #       B[[k]][i,j] = 0 if B[i,j] was estimated to be zero
  #       B[[k]][i,j] = 1 if B[i,j] was estimated as nonzero



  #for getting the statistics of a single model
  if (!is.list(B) && length(k)==1 ) {
    B<-list(B)
  }

  if( length(B) != length(k) ) {
    cat('Set indexes and number of models dont match!\n')
    browser()
    return(NA)
  }

  n<-nrow(B[[1]])

  zeroes<-0
  nonzeroes<-0

  confounders<-0

  zeroes_unknown<-0
  zeroes_zeroes<-0
  zeroes_nonzeroes<-0

  nonzeroes_unknown<-0
  nonzeroes_zeroes<-0
  nonzeroes_nonzeroes<-0

  #threshold for zeroes and nonzeroes
  threshold=1e-5

  I<-array(TRUE,c(n,n))
  diag(I)<-FALSE

  I2<-array(TRUE,c(n,n))
  diag(I2)<-FALSE
  I2[upper.tri(I2)]<-FALSE

  i<-1
  for( kk in k ) {
    T<-data.get(kk,only_model=TRUE)
    zeroes<-zeroes+ sum(abs(T$model$B[I]) < threshold )
    nonzeroes<-nonzeroes+ sum(abs(T$model$B[I]) > threshold )
    confounders<-confounders + sum(abs(T$model$Ce[I2]) > threshold )

    zeroes_unknown<-zeroes_unknown+ sum(abs(T$model$B[I]) < threshold & B[[i]][I]==(-1) )
    zeroes_zeroes<-zeroes_zeroes+ sum(abs(T$model$B[I]) < threshold & B[[i]][I]==0 )
    zeroes_nonzeroes<-zeroes_nonzeroes+ sum(abs(T$model$B[I]) < threshold & B[[i]][I]==1 )

    nonzeroes_unknown<-nonzeroes_unknown+ sum(abs(T$model$B[I]) > threshold & B[[i]][I]==(-1) )
    nonzeroes_zeroes<-nonzeroes_zeroes+ sum(abs(T$model$B[I]) > threshold & B[[i]][I]==0 )
    nonzeroes_nonzeroes<-nonzeroes_nonzeroes+sum(abs(T$model$B[I]) > threshold & B[[i]][I]==1 )
    i<-i+1
  }
  cat('globalVars:',globalVars,'globalExp:',globalExp,'globalSamples:',globalSamples,'globalSanity:',globalSanity,'\n')

  cat('Direct effect statistics of',length(k),'estimated models:\n')
  cat('   Zero in the true models:',zeroes ,' from which\n')
  cat('   ',zeroes_zeroes ,'were estimated CORRECTLY as zeroes\n')
  cat('   ',zeroes_unknown ,'were estimated as underdetermined\n')
  cat('   ',zeroes_nonzeroes ,'were estimated WRONGLY as nonzeroes\n')
  
  cat('   Non-zero in the true models:',nonzeroes ,' from which\n')
  cat('   ',nonzeroes_nonzeroes ,'were estimated CORRECTLY as non-zeroes\n')
  cat('   ',nonzeroes_unknown ,'were estimated as underdetermined\n')
  cat('   ',nonzeroes_zeroes ,'were estimated WRONGLY as zeroes\n')

  zeroes_percent<-zeroes_zeroes/(zeroes_zeroes+nonzeroes_zeroes)
  cat('   Percent correct when predicting zero: ',
        round(100*zeroes_percent,digits=1),'\n',sep='')

  nonzeroes_percent<-nonzeroes_nonzeroes/(nonzeroes_nonzeroes+zeroes_nonzeroes)
  cat('   Percent correct when predicting NON-zero: ',
        round(100*nonzeroes_percent,digits=1),'\n',sep='')
  
  cat('The models had ',confounders,' confounders of ', length(k)*(n*(n-1)/2),' possible.\n')

  list(zeroes=zeroes,nonzeroes=nonzeroes,confounders=confounders,
       zeroes_unknown=zeroes_unknown,zeroes_zeroes=zeroes_zeroes,zeroes_nonzeroes=zeroes_nonzeroes,
      nonzeroes_unknown=nonzeroes_unknown,nonzeroes_zeroes=nonzeroes_zeroes,nonzeroes_nonzeroes=nonzeroes_nonzeroes,
      zeroes_percent=zeroes_percent, nonzeroes_percent=nonzeroes_percent)
}
