data.stats2<-function(B,k=1:100,n) {

  #Prints the statistics for ALL experimental effects. 
  # where B[[k]][i] = -1 if effect [i] was not known to be zero or nonzero
  #       B[[k]][i] = 0 if effect [i] was estimated to be zero
  #       B[[k]][i] = 1 if effect [i] was estimated as nonzero
  # n is the number of variables


  #for getting the statistics of a single model
  if (!is.list(B) && length(k)==1 ) {
    B<-list(B)
  }

  if( length(B) != length(k) ) {
    cat('Set indexes and number of models dont match!\n')
    browser()
    return(NA)
  }

  zeroes<-0
  nonzeroes<-0

  zeroes_unknown<-0
  zeroes_zeroes<-0
  zeroes_nonzeroes<-0

  nonzeroes_unknown<-0
  nonzeroes_zeroes<-0
  nonzeroes_nonzeroes<-0

  #threshold for zeroes and nonzeroes
  threshold=1e-5

  i<-1
  for( kk in k ) {
    D<-data.get(kk,only_model=TRUE)

    T<-createParameterTable(n)
    true_values<-rep(NA,nrow(T))
    #should here test how good the found values are
    for ( t in 1:nrow(T) ) {
      true_values[t]<-experiment.canonical(D$model,dec.to.bin(T[t,4],n))$Cx[T[t,3],T[t,2]]
    }

    zeroes<-zeroes+ sum(abs(true_values) < threshold )
    nonzeroes<-nonzeroes+ sum(abs(true_values) > threshold )

    zeroes_unknown<-zeroes_unknown+ sum(abs(true_values) < threshold & B[[i]]==(-1) )
    zeroes_zeroes<-zeroes_zeroes+ sum(abs(true_values) < threshold & B[[i]]==0 )
    zeroes_nonzeroes<-zeroes_nonzeroes+ sum(abs(true_values) < threshold & B[[i]]==1 )

    nonzeroes_unknown<-nonzeroes_unknown+ sum(abs(true_values) > threshold & B[[i]]==(-1) )
    nonzeroes_zeroes<-nonzeroes_zeroes+ sum(abs(true_values) > threshold & B[[i]]==0 )
    nonzeroes_nonzeroes<-nonzeroes_nonzeroes+sum(abs(true_values) > threshold & B[[i]]==1 )
    i<-i+1
  }

  cat('Statistics for all experimental effects of',length(k),'estimated models:\n')
  cat('   Zero in the true models:',zeroes ,' from which\n')
  cat('   ',zeroes_zeroes ,'were estimated CORRECTLY as zeroes\n')
  cat('   ',zeroes_unknown ,'were estimated as undertermined\n')
  cat('   ',zeroes_nonzeroes ,'were estimated WRONGLY as nonzeroes\n')
  
  cat('   Non-zero in the true models:',nonzeroes ,' from which\n')
  cat('   ',nonzeroes_nonzeroes ,'were estimated CORRECTLY as non-zeroes\n')
  cat('   ',nonzeroes_unknown ,'were estimated as undertermined\n')
  cat('   ',nonzeroes_zeroes ,'were estimated WRONGLY as zeroes\n')
}


