createLinearEquations<-function(n,knowledge,limit=Inf,verbose = 1,mode='lininf',round=0) {
  #creates all equations, that are linear on the unknowns in 'knowledge'.
  #INPUT:
  #n - number of observer variables
  #knowledge - knowledge structure, see lininf
  #limit - when expanding a exp. effect, how much larger can the larger intervention set be
  #verbose - how much to print: 2 all info, verbose 1 usable equations verbose 0 for none
  #mode - 'lininf' for linear inference, 'heh' and 'ehs' for other tested methods
  #round - the number of linear inference round for processing pgm and aistats simulations

  #OUTPUT: Equation system Ax =b as list 
  #A <- list of A matrices, one for each resampled data set
  #b <- list of b vectors, one for each resampled data set
  #

  #verbose 
  #
  A<-list()
  B<-list()
  times<-ncol(knowledge$E)
  for ( iii in 1:times ) {
    A[[iii]]<-array(0,c(0,nrow(knowledge$T)) ) #having the extra zeroes here for easy indexing!
    B[[iii]]<-array(0,c(0,0))
  }

  #true values for nice printing
  true_values<-round(knowledge$T[,6],3)

  #adding equations from exp. effects equations
  if ( verbose >= 1 ) cat('Usable exp. effect equations:\n')
  index<-1
  for( i in 1:n ) { #expanding t(i->j||set)
    for( j in (1:n)[-i] ) {
      for ( s in 1:2^(n-2) ) { #always i in set, remaining n-2 elements apart from i and j may or may not be in the set
        set<-rep(0,n)
        set[-c(i,j)]<-dec.to.bin(s-1,n-2)
        set[i]<-1

	#index from expanding experimental effect
        expanding_from<-which( knowledge$T[,2] == i & knowledge$T[,3] == j & knowledge$T[,4] == bin.to.dec(set) )

        for ( s2 in 1:2^(n-2) ) { #this is the intervention set to which we will expand to
          set2<-rep(0,n)
          set2[-c(i,j)]<-dec.to.bin(s2-1,n-2)
          set2[i]<-1
          expanding_to<-which( knowledge$T[,2] == i & knowledge$T[,3] == j & knowledge$T[,4] == bin.to.dec(set2) )

          #this will be the equation
          a<-array(0,c(times,nrow(knowledge$T) ))
          b<-rep(0,times)

	  #if expanding_form equation is known it will be put to the right side b-vector
          if ( knowledge$T[expanding_from,5] ) { #i
            b<-b+knowledge$E[expanding_from,]
          } else { #if the exp. effect is unknown it is part of x with this coefficient
            a[,expanding_from]<-(-1)
          }

	  #similarly with exapanding to
          if ( knowledge$T[expanding_to,5] ) {
            b<-b-knowledge$E[expanding_to,]
          } else { #the coefficient has different sign though
            a[,expanding_to]<-1
          }

          if ( mode == 'heh' && sum(set) != n-1 && ( sum(set2) != n-1 || !knowledge$T[expanding_from,5] ) ) {
            #for heh mode only allow equations for which either set1 or set2 is all but one
            #also we must have knowledge about expanding from 
            next
          }
          if ( mode == 'ehs' && round == 1 && (sum(set) != 1 || !knowledge$T[expanding_to,5]) ) {
            #for aistats mode round 1 only allow equations for which either set1 or set2 is a singleton
            next
          }
          if ( mode == 'ehs' && round == 2 && (sum(set) != 1 || sum(set2) != n-1 || !knowledge$T[expanding_from,5]) ) {
            #for the second round only equations between totals and directs
            next
          }

	  #adding the equation if the following is satisfied
	  # set2 must be a proper superset of set
	  #the number of elements in set2-set can be limited (added sum when preparing the code pckg)
          if ( all(set2 >= set) && any(set2 != set) && sum(abs(set2-set)) < limit ) {

            if ( verbose >= 3 ) cat('Expanding ',rownames(knowledge$T)[expanding_from],'to',rownames(knowledge$T)[expanding_to],':\n')

            #records whether are any bilinear terms found (aka x*y where both are unknown
            bilinear<-FALSE

            #tells whether any element in the equation was unknown
            unknown<- knowledge$T[expanding_from,5]==0 || knowledge$T[expanding_to,5]==0
            
            ok_ehs<-TRUE #whether the equation was ok for the two simulations
            ok_heh<-TRUE
            #strings for printing the equation
            biterms<-''
            biterms2<-''

            for (k in which( (set2-set) == 1 ) ) {
	      #for each term that is in set2 and not in set there will be a bilinear term
	      # t(i->k||set)*t(k->j||set2)

	      #if both elements are unknown then this equation cannot be used,
	      #otherwise we need to add the proper elements to matrix A and vector b
	      #and give the equation in nice printing form

              #getting the indexed  
              first_term<-which( knowledge$T[,2] == i & knowledge$T[,3] == k & knowledge$T[,4] == bin.to.dec(set) )
              second_term<-which( knowledge$T[,2] == k & knowledge$T[,3] == j & knowledge$T[,4] == bin.to.dec(set2) )

	      #if either the product is know to be zero or either term is known to be zero, the term can be ignored
              if ( (knowledge$Z[first_term,second_term] | knowledge$T[first_term,7]==1 | knowledge$T[second_term,7] == 1 ) && mode=='uai' ) {
                #if ( verbose >= 3 ) cat(' (Term',rownames(knowledge$T)[first_term],'*',rownames(knowledge$T)[second_term],'=0 by Z.)\n')
                biterms2<-paste(biterms2,'+{',true_values[first_term],'}*{',true_values[second_term],'}')
                biterms<-paste(biterms,'+{',rownames(knowledge$T)[first_term],'}*{',rownames(knowledge$T)[second_term],'}')
                next
              }

              #this is a new addition to the uai procedure
	      #here both terms are known and they are not known to be zero
	      #the term is added to b vector,consisting of known elements
              if ( knowledge$T[first_term,5] && knowledge$T[second_term,5] &&  !knowledge$Z[first_term,second_term] ) {
                 #both terms are known
                 b<-b-knowledge$E[first_term,]*knowledge$E[second_term,]
                 biterms2<-paste(biterms2,'+[',true_values[first_term],']*[',true_values[second_term],']')
                 biterms<-paste(biterms,'+[',rownames(knowledge$T)[first_term],']*[',rownames(knowledge$T)[second_term],']')
                 next
              }
	      
	      # first term is known the second term is unknown
              if ( knowledge$T[first_term,5] && !knowledge$T[second_term,5] &&  !knowledge$Z[first_term,second_term] ) {
                #first term is known second term is unknown
                ok_ehs<- ok_ehs && round == 2  #only OK for aistats in round 2, since only then b:s are considered as unknown
                unknown<-TRUE
                a[,second_term]<- knowledge$E[first_term,] #adding the first term as a coefficient for the second term
                biterms2<-paste(biterms2,'+[',true_values[first_term],']*(',rownames(knowledge$T)[second_term],')')
                biterms<-paste(biterms,'+[',rownames(knowledge$T)[first_term],']*(',rownames(knowledge$T)[second_term],')')
                next
              }

              if ( !knowledge$T[first_term,5] && knowledge$T[second_term,5] &&  !knowledge$Z[first_term,second_term] ) {
                #first term is unknown second term is known
                ok_heh<-FALSE #for pgm simulation only the exprimental effect with larger set size can be unknown
                ok_ehs<- ok_ehs && round == 1#only OK for first round where total are unknowns
                unknown<-TRUE
                a[,first_term]<- knowledge$E[second_term,]
                biterms2<-paste(biterms2,'+(',rownames(knowledge$T)[first_term],')*[',true_values[second_term],']')
                biterms<-paste(biterms,'+(',rownames(knowledge$T)[first_term],')*[',rownames(knowledge$T)[second_term],']')
                next
              }


	      #if both terms are unknown the term is bilinear term and the equation is unusable
              if ( !knowledge$T[first_term,5] && !knowledge$T[second_term,5] ) {
                if ( verbose >= 3 ) cat(' (Not usable since ', rownames(knowledge$T)[first_term],'*',
                     rownames(knowledge$T)[second_term], 'is bilinear.)\n')
                bilinear<-TRUE
                next
              }
            }

            if ( !unknown ) {
                if ( verbose >= 3 ) cat(' (Not usable since no unknowns.)\n')
            }

            #Equation is unusable if
	    # it has a bilinear terms, or when no terms are unknown
            usable<- !bilinear & unknown

	    #is the equation OK for the two simulations fif the mode happens to be one of them
            if ( mode == 'ehs') {
              usable <- usable && ok_ehs
            }
            if ( mode == 'heh') {
              usable <- usable && ok_heh
            }

	    #some printing stuff
            if ( knowledge$T[expanding_to,5] ) {
              toname<-paste('[',rownames(knowledge$T)[expanding_to],']')
              toname2<-paste('[',true_values[expanding_to],']')
            } else {
              toname<-paste('(',rownames(knowledge$T)[expanding_to],')')
              toname2<-paste('(',rownames(knowledge$T)[expanding_to],')')
            }
            if ( knowledge$T[expanding_from,5] ) {
              fromname<-paste('[',rownames(knowledge$T)[expanding_from],']')
              fromname2<-paste('[',true_values[expanding_from],']')
            } else {
              fromname<-paste('(',rownames(knowledge$T)[expanding_from],')')
              fromname2<-paste('(',rownames(knowledge$T)[expanding_from],')')
            }

            if ( usable && verbose >= 1)  cat(' -',fromname,'+',toname,biterms,'= 0\n')
            if ( ( usable && verbose >= 3) ) cat(' -',fromname2,'+',toname2,biterms2,'= 0\n')


            if ( usable ) {# if equation passed the tests, adding it into the equation to the system
              #browser()
              #if ( is.na(b) ) browser()
              for ( t in 1:times) {
                A[[t]]<-rbind(A[[t]],a[t,])
                B[[t]]<-c(B[[t]],b[t])
              }
              index<-index+1
            }
          }


        }
        #if ( verbose >= 2 ) cat('\n')
      }
    }
  }


  #finally adding equations using the knowledge Z matrix
  # these are equations t() * t() = 0 by the element in the Z matrix
  # and one of the terms is known not to nonzero
  if ( verbose >= 1 ) cat('Usable zero equations:\n')
  #browser()

  if (  mode != 'ehs' ) { #mode != 'pgm' && some equations given by F should be used in the PGM mode
    for ( i in 1:nrow(knowledge$T) ) {
      for ( j in (1:nrow(knowledge$T))[-i] ) {
        #cat('(',i,',',j,')',sep='')
        if ( !knowledge$Z[i,j] ) next 
        #cat('.')
        #notice that the iteration does the pair (i,j) in both orders
        if ( knowledge$T[i,5]==1 && knowledge$T[j,5]==0 && knowledge$T[i,8]==1 ) { #last makes sure it is really nonzero
          #we can add equation putting knowledge$T[j,5]==0 to zero!
          if ( verbose >= 1) cat('[',rownames(knowledge$T)[i],']*(',rownames(knowledge$T)[j],')=0\n')
          if ( verbose >= 3) cat('[',true_values[i],']*(',rownames(knowledge$T)[j],')=0\n')

	  #adding the term as a quations
          a<-array(0,c(times,nrow(knowledge$T) ))
          b<-rep(0,times)

          a[,j]<-knowledge$E[i,]

          for ( t in 1:times) {
            A[[t]]<-rbind(A[[t]],a[t,])
            B[[t]]<-c(B[[t]],b[t])
          }
          index<-index+1
        }
      }
    }
  } #if mode not pgm or aistats
  if( verbose >= 3 ) print(cbind(A,B))
  cat('\nTotal of ', index-1,' usable equations.\n')

  #returning finally the equations
  list(A=A,b=B)
}