createParameterTable<-function(n) {
  #Creates a table of experimental effects and info on them.
  # INPUT:
  # n - number of observed variables considered.
  # OUTPUT:
  # Array, columns are the following.
  # id  - running parameter index number
  # from,to - experimental effect t(from -> to || set)
  # set - integer version of the intervention set, see dec.to.bin,bin.to.dec for conversions
  # known - 1 if the parameter value is known, 0 otherwise
  # zero - 1 if the parameter value is known to be zero, 0 otherwise
  # nonzero - 1 if the parameter value is known to be nonzero, 0 otherwise
  # true - possibly inputed true value for the parameter in question
  #
  # Rownames correspond to user friendly notation t(1->2||1,3).

  T<-array(NA,c(n*(n-1)*2^(n-2),9) )

  colnames(T)<-c('id','from','to','set','known','value','zero','nonzero','true')

  names<-rep('',(n*(n-1)*2^(n-2)))

  T[,1]<-1:(n*(n-1)*2^(n-2)) #setting indexes for the parameters
  index<-1

  for ( i in 1:n) { #from and to
    for( j in (1:n)[-i] ) {
      for ( s in 1:2^(n-2) ) { #additional elements in the intervention set
        set<-rep(0,n)
        set[-c(i,j)]<-dec.to.bin(s-1,n-2)
        set[i]<-1
        T[index,2:9]<-c(i,j,bin.to.dec(set),FALSE,NA,0,0,NA)
        names[index]<-paste('t(',i,'->',j,'||',paste(which(set==1),collapse=','),')',sep='')
        index<-index+1
      }
    }
  }

  rownames(T)<-names

  T
}