experiment.canonical<-function(M, newexp=NULL) {
  #Gives out the covariance matrix of model M in experiment newexp.
  # In the experiment the intervened variables are intervened with zero mean and unit variance.
  #M - a list structure where M$B is the coefficient matrix and M$Ce is the disturbance cov. matrix 
  #newexp - a vector where 1 means variable is intervened, 0 it is observed, -1 unobserved
  #
  #Returns a list(e=newexp, Cx=Cx) where Cx is the covariance matrix.

  #cat('c')
  #canonical model has B and Ce matrices as parameters
  n<-nrow(M$B)

  while ( is.null(newexp) #|| all( newexp == 1 ) || all( newexp == 0 ) commented out for completeness test 
    ) {
     newexp <- 1*(runif(n)>0.5)
  }

  eye<-diag(n)
  Jk<-diag(1*(newexp == 1))
  Uk<-eye-Jk

  #See for example the "Learning Linear Cyclic Causal Models with Latent Variables" for these formulas
  Cek<-Jk+Uk%*%M$Ce%*%Uk
  Tek<-mpinv(eye-Uk%*%M$B) #mpinv is better here

  Cxk<-Tek%*%Cek%*%t(Tek)

  #marginalize the variables marked with -1, as unobserved
  Cxk[newexp==(-1),]<-NA
  Cxk[,newexp==(-1)]<-NA

  E<-list()
  E$e <- newexp
#  E$E <- Tek
  E$Cx <- Cxk

  E
}