lininf.loop<-function( sets=1:100,samples=FALSE,mode='lininf',save=FALSE) {



  #These are set before
  #globalVars<<-6
  #globalExp<<-5
  #globalSanity<<-FALSE
  #globalSamples<<-10000

  #setting what was used in the paper tests

  #significance levels used
  zero_significance<-0.1
  nonzero_significance<-0.01

  if ( samples ) { #setting maximum conditioning set size
    maxCset<-1
  } else {
    maxCset<-Inf
  }


  if ( mode == 'lininf' ) {
    faithful=TRUE
    if ( samples ) {
      max_rounds<-1
    } else {
      max_rounds<-Inf
    }

  } else if ( mode == 'ehs' ) {
    faithful=FALSE
    max_rounds<-2

  } else if ( mode == 'heh' ) {
    faithful=TRUE
    max_rounds<-1
  }


  threshold<-1e-5
  B<-list()
  B2<-list()
  #sets<-1:10
 
  if (samples ) { #when using samples, use resampling
    times<-20
  } else { #when not using sample data, dont resample
    times<-1
  }

  Bi<-1
  for ( i in sets) {

    D<-data.get(i)
    n<-ncol(D$E)



    #prepare the data for nec2
    DATA<-list()
    for ( t in 1:nrow(D$E) ) {
      #Testing of which extra dependencies and independencies are found in sample data
      #if (!is.infinite(samples) && length(sets)==1 ) {
        #faithtest<-test.f(D$Cx_sample[[t]],D$Cx[[t]],significance=0.05,samples=nrow(D$X[[t]]),D$E[t,])
        #print(faithtest)
        #browser()
      #}
      if ( !samples ) { #if samples is FALSE use "accurate" covariance matrix
        DATA[[t]]<-list(Cx=D$Cx[[t]],N=Inf,e=D$E[t,])
      } else { #otherwise use the sample estimate of the covariance matrix
        DATA[[t]]<-list(Cx=D$Cx_sample[[t]],X=D$X[[t]],N=nrow(D$X[[t]]),e=D$E[t,])
      }
    }

    #for convenience of printing and checking the algorithm performance
    #determining the true values here
    T<-createParameterTable(n)
    true_values<-rep(NA,nrow(T))
    #should here test how good the found values are
    for ( t in 1:nrow(T) ) {
      true_values[t]<-experiment.canonical(D$model,dec.to.bin(T[t,4],n))$Cx[T[t,3],T[t,2]]
    }
    
    knowledge<-lininf(DATA,true_values=true_values,times=times,
                              max_rounds=max_rounds,faithful=faithful,maxCset=maxCset,
                              zero_significance=zero_significance,nonzero_significance=nonzero_significance,mode=mode)

    #saving the found knowledge structure
    #save(knowledge,file=paste('datarep2/K',mode,'_',globalVars,'_',globalExp,'_',samples,'_',i,'.Rdata',sep=''))

    #Saving the B matrix to a list.
    BB<-knowledge.to.B(knowledge)
    B[[Bi]]<- BB

    #creating a vector to save all experimental effects.
    bvec<-rep(-1,nrow(knowledge$T))
    #converting the knowledge to the vector.
    bvec[knowledge$T[,7]==1]<-0
    bvec[knowledge$T[,8]==1]<-1
    B2[[Bi]]<-bvec

    #incrementing the index for next round
    Bi<-Bi+1
  }

  #print statistics for direct effects only, aka model coefficients
  results<-data.stats(B,sets)

  if ( save ) {
    #saving the results for plotting
    if ( samples ) {
      file=paste('results/',mode,'_',globalSamples,'.Rdata',sep='')
    } else {
      file=paste('results/',mode,'_',Inf,'.Rdata',sep='')
    }
    save(results,file=file)
  }
  #print out also the results for all experimental effects
  data.stats2(B2,sets,globalVars)

  #printing stats for the algorithm configuration for checking
  cat('Linear Inference algorithm configuration:\n')
  cat('Mode:',mode,'\n')
  cat('Faithfulness used:',faithful,'\n')
  cat('Actual samples used:',samples,'\n')
  cat('Times resampled:',times,'\n')
  cat('Max rounds:',max_rounds,'\n')
  cat('MaxCset:',maxCset,'\n')
  cat('zero_significance=',zero_significance,'\n')
  cat('nonzero_significance=',nonzero_significance,'\n')

}