main<-function( task=1, theseed=-1 ) {
  #Main function for running the code.
  #task - task number to run 
  #  	1-4	for simple tests, 
  #	101-112	for all plot results
  #	201-202 for plotting like in the paper
  #	301	for the case study in the paper

  if ( theseed == -1 ) {
    theseed<-round(proc.time()[3]*1000)
  }
  set.seed(theseed)
  if ( any(task > 100 ) ) {
    #these are the numbers used for the paper tests
    globalVars<<-n<-6
    globalExp<<-5
    globalSanity<<-FALSE
  } else {
    #using a bit smaller models to see the operation principles
    globalVars<<-n<-4
    globalExp<<-3
    globalSanity<<-FALSE
  }

  #if running the inference for simple examples decide
  # - data set index
  # - the number of samples to generate per experiment
  # - whether the data samples are used or whether to use covariance
  # matrices in the infinite sample limit 

  if ( any( task >=1 && task <= 4 ) ) {
    #draw a random sample size
    datai<-round(runif(1)*100000)
    cat('Data set index:',datai,'\n')

    globalSamples<<-sample(c(1000,10000),1)
    cat('Samples to create in each experiment:',globalSamples,'\n')

    infinite.inference<<-sample(c(TRUE,FALSE),1)
    cat('Using true covariance matrices in inference:',infinite.inference,'\n')
  }

  if ( any(task==1 ) ) {
    cat('Running Linear Inference algorithm...\n')
    #random data set index
    lininf.loop(datai,samples=!infinite.inference, mode='lininf' ) 

  }

  if ( any(task==2) ) {
    cat('Running BiLinear Inference algorithm...\n')
    bilin.loop(useTrueCov=infinite.inference,thecases=datai )
  }

  if ( any(task==3) ) {
    cat('Running EHS-method algorithm...\n')
    lininf.loop(datai,samples=!infinite.inference, mode='ehs' ) 
  }
 
  if ( any(task==4) ) {
    cat('Running HEH-method...\n')
    lininf.loop(datai,samples=!infinite.inference, mode='heh' ) 
  }

########################################################################################
########################################################################################
########################################################################################

  if (any(task == 101) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-10 #setting the number of samples to very low
    lininf.loop( mode='lininf',samples=FALSE,save=TRUE )
  }
  if (any(task == 102) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-10000
    lininf.loop( mode='lininf',samples=TRUE,save=TRUE )
  }
  if (any(task == 103) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-1000
    lininf.loop( mode='lininf',samples=TRUE,save=TRUE )
  }
  if (any(task == 104) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
   globalSamples<<-10
    lininf.loop( mode='heh',samples=FALSE,save=TRUE )
  }
  if (any(task == 105) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-10000
    lininf.loop( mode='heh',samples=TRUE,save=TRUE )
  }
  if (any(task == 106) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-1000
    lininf.loop( mode='heh',samples=TRUE,save=TRUE )
  }
  if (any(task == 107) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
   globalSamples<<-10
    lininf.loop( mode='ehs',samples=FALSE,save=TRUE )
  }
  if (any(task == 108) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-10000
    lininf.loop( mode='ehs',samples=TRUE,save=TRUE )
  }
  if (any(task == 109) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-1000
    lininf.loop( mode='ehs',samples=TRUE,save=TRUE )
  }
  if (any(task == 110) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-10
    bilin.loop(useTrueCov=TRUE,save=TRUE )
  }
  if (any(task == 111) ) {
    cat('Running the inference procedures for plotting, might take time...\n')
    globalSamples<<-10000  
    bilin.loop(save=TRUE)
  }
  if (any(task == 112) ) {
    globalSamples<<-1000
    cat('Running the inference procedures for plotting, might take time...\n')
    bilin.loop(save=TRUE)
  }

#################################################################################
#################################################################################
#################################################################################

  if ( any(task==201) ) {
    plot1()
  }
  if ( any(task==202) ) {
    plot2()
  }

#################################################################################
#################################################################################
#################################################################################

  if ( any(task== 301) ) {
    casestudy()
  }

  cat('Used seed:', theseed,'\n')
}