plot1<-function(pdf=TRUE) {
  #Plots a figure on the accuracies of the predicted links and absences.
  #pdf - TRUE if outputted into a file, FALSE if on screen.


  algorithm_modes<-c('ehs','heh','bilin','lininf')
  sample_modes<-c('1000','10000','Inf')

  #saving the predicted percents
  absences<-presences<-array(0,c( length(algorithm_modes),length(sample_modes) ) )
 
  for ( i in 1:length(algorithm_modes) ) {
    for ( j in 1:length(sample_modes) ) {
      file<-paste('results/',algorithm_modes[i],'_',sample_modes[j],'.Rdata',sep='')
      if ( file.exists(file) ) {
	load(file)
	#print(results)
	absences[i,j]<-results$zeroes_percent
	presences[i,j]<-results$nonzeroes_percent
      } else {
	cat('Warning file',file, 'does not exist. Using zeroes.\n')
      }
    }
  }
  cat('Presence percentages:\n')
  print(presences)

  cat('Absence percentages:\n')
  print(absences)

  algorithms<-1:4
  algorithm_names<-c('EHS','HEH','BILIN','LININF')

  pch<-c(15,17,16,18)#15:18

  colors<-c('red','blue','dark green','magenta')

  if ( pdf ) {
    pdf(file='plot1.pdf',11,6)
  }

  sample_sizes<-c(1,2,3)
  sample_names<-c('1000','10 000', 'Inf')
  

  lwd<-3

  par(mfcol=c(1,2),oma=c(0,0,0,0))
##############################################################################################
  par(mfg=c(1,1),mai=c(0.9,0.9,0.3,0.3),cex=1.5,lwd=2)

  plot(c(-100,200000),c(1,1),type='l',ylim=c(0.64,1.01), #c(0.49,1.01)
        xlim=c(1,3),main='Correctness of pred. absences',
                xlab='',ylab='',axes=FALSE)
  box()
# axis(2,at=c(0.5,0.75,1.0),labels=c('50%','75%','100%'),lwd=2 )
  axis(2,at=c(0.7,0.8,0.9,1.0),labels=c('70%','80%','90%','100%'),lwd=2 )

  axis(1,at=sample_sizes,labels=sample_names,lwd=2 )
  mtext('Correct predictions',side=2,line=2,cex=1.5)
  mtext('Samples/Experiment',side=1,line=2,cex=1.5)

  lines(c(1,2,3),absences[1,],type='b',pch=pch[1],cex=1.1,col=colors[1],lwd=3)
  lines(c(1,2,3),absences[2,],type='b',pch=pch[2],cex=1.1,col=colors[2],lwd=3)
  lines(c(1,2,3),absences[3,],type='b',pch=pch[3],cex=1.1,col=colors[3],lwd=3)
  lines(c(1,2,3),absences[4,],type='b',pch=pch[4],cex=1.1,col=colors[4],lwd=3)

  legend('bottomright',NULL,algorithm_names,pch=pch,col=colors,pt.lwd=3)

##############################################################################################
  par(mfg=c(1,2),mai=c(0.9,0.9,0.3,0.3),cex=1.5,lwd=2)


    plot(c(-100,200000),c(1,1),ylim=c(0.64,1.01) # c(0.49,1.01)
            ,type='l', #was 25
              xlim=c(1,3),main='Correctness of pred. links',
                xlab='',ylab='',axes=FALSE)
  box()

  axis(2,at=c(0.7,0.8,0.9,1.0),labels=c('70%','80%','90%','100%'),lwd=2 )

  axis(1,at=sample_sizes,labels=sample_names,lwd=2)
  mtext('Correct predictions',side=2,line=2,cex=1.5)
  mtext('Samples/Experiment',side=1,line=2,cex=1.5)


  lines(c(1,2,3),presences[1,],type='b',pch=pch[1],cex=1.1,col=colors[1],lwd=3)
  lines(c(1,2,3),presences[2,],type='b',pch=pch[2],cex=1.1,col=colors[2],lwd=3)
  lines(c(1,2,3),presences[3,],type='b',pch=pch[3],cex=1.1,col=colors[3],lwd=3)
  lines(c(1,2,3),presences[4,],type='b',pch=pch[4],cex=1.1,col=colors[4],lwd=3)

  if ( pdf ) {
    cat('See plot1.pdf!\n')
    dev.off()
  }
}



