plot2<-function(pdf=TRUE) {
  #Plots a figure on overall number of predictions for different algorithms.
  #pdf - TRUE if outputted into a file, FALSE if on screen.



  algorithm_modes<-c('ehs','heh','bilin','lininf')
  sample_modes<-c('1000','Inf') #'10000' was not plotted

  #saving the predicted percents
  #in these the first word refers to truth always

  zeroes_zeroes<-zeroes_nonzeroes<-nonzeroes_zeroes<-nonzeroes_nonzeroes<-array(0,c( length(algorithm_modes),length(sample_modes) ) )
 
  for ( i in 1:length(algorithm_modes) ) {
    for ( j in 1:length(sample_modes) ) {
      file<-paste('results/',algorithm_modes[i],'_',sample_modes[j],'.Rdata',sep='')
      if ( file.exists(file) ) {
	load(file)
	print(file)
	print(c(results$zeroes,results$nonzeroes))
	zeroes_zeroes[i,j]<-results$zeroes_zeroes
	zeroes_nonzeroes[i,j]<-results$zeroes_nonzeroes
	nonzeroes_zeroes[i,j]<-results$nonzeroes_zeroes
	nonzeroes_nonzeroes[i,j]<-results$nonzeroes_nonzeroes
      } else {
	cat('Warning file',file, 'does not exist. Using zeroes.\n')
      }
    }
  }

  algorithms<-1:4
  algorithm_names<-c('EHS','HEH','BILIN','LININF')
  pch<-15:18
  colors<-c('blue','red')

  if ( pdf ) {
    pdf(file='plot2.pdf',12,12)
  }

  zeromax<-2000
  nonzeromax<-300
  lwd<-3

  par(mfcol=c(2,2),oma=c(0,2,0,0))



##############################################################################################
  par(mfg=c(1,1),mai=c(0.9,0.9,0.3,0.3),cex=1.5,lwd=2)

#  correct<-c(32,1338,1376,1506)
#  incorrect<-c(0,33,64,78)
  correct<- zeroes_zeroes[,1]
  incorrect<- nonzeroes_zeroes[,1]

  barplot(rbind(correct,incorrect),col=colors,ylim=c(0,zeromax),names.arg=algorithm_names,main='Number of predicted absences')


  mtext('Infinite sample limit                  1000 samples/exp.',side=2,line=0,cex=2.5,outer=TRUE)


##############################################################################################
  par(mfg=c(1,2),mai=c(0.9,0.9,0.3,0.3),cex=1.5,lwd=2)

#  correct<-c(10,73,126,142)
#  incorrect<-c(3,1,74,17)
  correct<- nonzeroes_nonzeroes[,1]
  incorrect<- zeroes_nonzeroes[,1]


  barplot(rbind(correct,incorrect),col=colors,ylim=c(0,nonzeromax),names.arg=algorithm_names,main='Number of predicted links')

  #mtext('1000 samples/exp.',side=2,line=2,cex=2)

  legend('topright',NULL,c('correct','incorrect'),pch=pch[1],col=colors,pt.lwd=3)


############################################################################################
  par(mfg=c(2,1),mai=c(0.9,0.9,0.3,0.3),cex=1.5,lwd=2)

#  correct<-c(123,1533,1591,1724)
#  incorrect<-c(0,0,17,0)
  correct<- zeroes_zeroes[,2]
  incorrect<- nonzeroes_zeroes[,2]


  barplot(rbind(correct,incorrect),col=colors,ylim=c(0,zeromax),names.arg=algorithm_names,main='Number of predicted absences')

 # mtext('Infinite sample limit',side=2,line=2,cex=2)


##############################################################################################
  par(mfg=c(2,2),mai=c(0.9,0.9,0.3,0.3),cex=1.5,lwd=2)

#  correct<-c(23,108,184,232)
#  incorrect<-c(0,0,1,0)
  correct<- nonzeroes_nonzeroes[,2]
  incorrect<- zeroes_nonzeroes[,2]

  barplot(rbind(correct,incorrect),col=colors,ylim=c(0,nonzeromax),names.arg=algorithm_names,main='Number of predicted links')

  #mtext('Infinite sample limit',side=2,line=2,cex=2)

  if ( pdf ) {
    cat('See plot2.pdf!\n')
    dev.off()
  }
}
